import { createRequire } from "node:module";
import chalk from "chalk";
const require = createRequire(import.meta.url);
const cliui = require("cliui");
const maxLengthMetadata = 24;
export default class UITable {
    _ui;
    _depsMaxLength;
    _name;
    _path;
    constructor(options) {
        this._ui = cliui({});
        this._depsMaxLength =
            options.depsMaxLength === 0 ? 6 : Math.max(options.depsMaxLength, 4);
        this._name = options.name ?? "unknown";
        this._path = options.path;
        this._ui.div({
            padding: [1, 1, 0, 1],
            text: chalk.cyan.bold(`Report for ${this._name} (${this._path})`),
        });
        this._ui.div(this.toRowColumn(chalk.bold("Name"), this._depsMaxLength), this.toRowColumn(chalk.bold("Last Publish"), maxLengthMetadata), this.toRowColumn(chalk.bold("Latest Version"), maxLengthMetadata));
    }
    toRowColumn(text, width) {
        return {
            padding: [0, 1, 0, 1],
            text,
            ...(width && { width: width + 2 }),
        };
    }
    addRow(dep, lastUpdate, latestVersion) {
        this._ui.div(this.toRowColumn(dep, this._depsMaxLength), this.toRowColumn(lastUpdate, maxLengthMetadata), this.toRowColumn(latestVersion, maxLengthMetadata));
    }
    resetOutput() {
        return this._ui.resetOutput();
    }
    toString() {
        return this._ui.toString();
    }
}
